"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const get_bounding_rect_1 = __importDefault(require("./get-bounding-rect"));
const coordinates_1 = require("./coordinates");
const optimizeTextParts = (inputParts, viewport) => {
    const sensitivity = 1 / (viewport.scale === 0 ? 1 : viewport.scale);
    console.log("optimizeTextParts sensitivity:", sensitivity);
    const [pageWidth, pageHeight] = viewport.viewBox;
    const parts = inputParts.filter((part) => part.text && part.text.trim() !== "");
    if (parts.length === 0) {
        return {
            text: '',
            textParts: [],
            pageSize: { width: pageWidth, height: pageHeight },
        };
    }
    const result = [];
    let last = Object.assign({}, parts[0]);
    for (let i = 1; i < parts.length; i++) {
        const current = parts[i];
        if (current.rect.top < last.rect.top + last.rect.height - sensitivity) {
            const lastChar = last.text.length && last.text[last.text.length - 1];
            const firstChar = current.text.length && current.text[0];
            const isAddSpace = lastChar &&
                firstChar &&
                lastChar !== ' ' &&
                lastChar !== '\t' &&
                firstChar !== ' ' &&
                firstChar !== '\t';
            last.rect = (0, get_bounding_rect_1.default)([last.rect, current.rect]);
            last.text = last.text + (isAddSpace ? ' ' : '') + current.text;
        }
        else {
            result.push(last);
            last = Object.assign({}, current);
        }
    }
    result.push(last);
    const res = {
        text: result.map((x) => x.text).join('\n'),
        textParts: result.map((r) => {
            const rect = r.rect;
            return {
                text: r.text,
                rect: (0, coordinates_1.viewportToPdf)(rect, viewport),
                usePdfCoordinates: true,
            };
        }),
        pageSize: { width: pageWidth, height: pageHeight },
    };
    return res;
};
exports.default = optimizeTextParts;
//# sourceMappingURL=optimize-text-parts.js.map