import getBoundingRect from "./get-bounding-rect";
import { viewportToPdf } from "./coordinates";
const optimizeTextParts = (inputParts, viewport) => {
    const sensitivity = 1 / (viewport.scale === 0 ? 1 : viewport.scale);
    console.log("optimizeTextParts sensitivity:", sensitivity);
    const [pageWidth, pageHeight] = viewport.viewBox;
    const parts = inputParts.filter((part) => part.text && part.text.trim() !== "");
    if (parts.length === 0) {
        return {
            text: '',
            textParts: [],
            pageSize: { width: pageWidth, height: pageHeight },
        };
    }
    const result = [];
    let last = Object.assign({}, parts[0]);
    for (let i = 1; i < parts.length; i++) {
        const current = parts[i];
        if (current.rect.top < last.rect.top + last.rect.height - sensitivity) {
            const lastChar = last.text.length && last.text[last.text.length - 1];
            const firstChar = current.text.length && current.text[0];
            const isAddSpace = lastChar &&
                firstChar &&
                lastChar !== ' ' &&
                lastChar !== '\t' &&
                firstChar !== ' ' &&
                firstChar !== '\t';
            last.rect = getBoundingRect([last.rect, current.rect]);
            last.text = last.text + (isAddSpace ? ' ' : '') + current.text;
        }
        else {
            result.push(last);
            last = Object.assign({}, current);
        }
    }
    result.push(last);
    const res = {
        text: result.map((x) => x.text).join('\n'),
        textParts: result.map((r) => {
            const rect = r.rect;
            return {
                text: r.text,
                rect: viewportToPdf(rect, viewport),
                usePdfCoordinates: true,
            };
        }),
        pageSize: { width: pageWidth, height: pageHeight },
    };
    return res;
};
export default optimizeTextParts;
//# sourceMappingURL=optimize-text-parts.js.map